@@ -1,6 +1,6 @@
 import string
 import pyautogui as pyautogui
-import cv2 # locate image confidece support
+# import cv2 # locate image confidece support
 from script.utils.utils import resource_path
 
 secs_between_keys = 0.1
